# laminar

> "slow is smooth, and smooth is fast"

`laminar` is the workflow framework that works for you. It aims to be a modern container first framework that enables you to rapidly go from local development into production as quickly as possible.

## Documentation

https://rchui.github.io/laminar/

## Getting Started

To install the latest release of `laminar`:

```bash
pip install laminar
```

## Contributing

We welcome contributions to laminar.
